@@ -24,7 +24,7 @@ use Encode 'decode';
 
 sub get_TK_version {
     # Stick with %.2f format - 4.50 vice 4.5
-    return '5.22';
+    return '5.23';
 }
 
 sub get_path {
@@ -455,6 +455,8 @@ sub translate {
     $a = _( 'Advanced' );
     $a = _( 'Scan a file' );
     $a = _( 'Scan a directory' );
+    # From the About dialog
+    $a = _( 'ClamTk is a graphical front-end for Clam Antivirus' );
 
     return $a;
 }
